NoOptionalOperatorsInTests class

A lint rule that forbids using optional operators (?., ??) in test files.

This rule flags optional operators in test blocks to ensure tests fail explicitly at the point of failure rather than silently handling nulls.

Example of code that triggers this rule:

test('example', () {
  final result = someObject?.someProperty;  // LINT
  final value = someValue ?? defaultValue;  // LINT
});

Example of code that doesn't trigger this rule:

test('example', () {
  expect(someObject, isNotNull);
  final result = someObject.someProperty;
  expect(someValue, isNotNull);
  final value = someValue;
  final assertion = someValue!;  // This is fine
});

Constructors

NoOptionalOperatorsInTests()
const

Properties

code → LintCode
The LintCode that this LintRule may emit.
finalinherited
enabledByDefault bool
Whether the lint rule is on or off by default in an empty analysis_options.yaml
no setterinherited
filesToAnalyze List<String>
A list of glob patterns matching the files that run cares about.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFixes() List<Fix>
Obtains the list of Fix associated with this LintRule.
inherited
isEnabled(CustomLintConfigs configs) bool
Checks whether this lint rule is enabled in a configuration file.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(CustomLintResolver resolver, ErrorReporter reporter, CustomLintContext context) → void
Emits lints for a given file.
startUp(CustomLintResolver resolver, CustomLintContext context) Future<void>
Emits lints for a given file.
inherited
testAnalyzeAndRun(File file) Future<List<AnalysisError>>
Analyze a Dart file and runs this assist in test mode.
inherited
testRun(ResolvedUnitResult result, {Pubspec? pubspec}) Future<List<AnalysisError>>
Runs this assist in test mode.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited