NoDirectInstantiation class

Enforces dependency injection for better testability of auth/sync components.

This rule flags all direct instantiations of classes, except:

  • Classes whose names end with 'Factory' (e.g., FileProcessorFactory)
  • Classes that extend 'Module'
  • Any instantiation that occurs inside a class that extends 'Module'

Example:

// ❌ Not allowed:
fakeSupabaseWrapper = FakeSupabaseWrapper();
final service = AuthService();

// ✅ Allowed:
fakeSupabaseWrapper = Modular.get<FakeSupabaseWrapper>();
final service = Modular.get<AuthService>();
final factory = FileProcessorFactory();
final module = AppModule();

// ✅ Allowed: Instantiation inside a Module
class AppModule extends Module {
  AppModule() {
    final service = AuthService(); // Allowed here
  }
}

Constructors

NoDirectInstantiation()
const

Properties

code → LintCode
The LintCode that this LintRule may emit.
finalinherited
enabledByDefault bool
Whether the lint rule is on or off by default in an empty analysis_options.yaml
no setterinherited
filesToAnalyze List<String>
A list of glob patterns matching the files that run cares about.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFixes() List<Fix>
Obtains the list of Fix associated with this LintRule.
inherited
isEnabled(CustomLintConfigs configs) bool
Checks whether this lint rule is enabled in a configuration file.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(CustomLintResolver resolver, ErrorReporter reporter, CustomLintContext context) → void
Emits lints for a given file.
startUp(CustomLintResolver resolver, CustomLintContext context) Future<void>
Emits lints for a given file.
inherited
testAnalyzeAndRun(File file) Future<List<AnalysisError>>
Analyze a Dart file and runs this assist in test mode.
inherited
testRun(ResolvedUnitResult result, {Pubspec? pubspec}) Future<List<AnalysisError>>
Runs this assist in test mode.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited