NoInternalMethodDocs class
A lint rule that forbids documentation on private methods to reduce documentation noise.
This rule flags private methods that have documentation comments, as these are internal implementation details that don't need to be documented for external consumers. This reduces documentation noise and focuses on public API documentation.
Example of code that triggers this rule:
/// Handles internal auth state
void _handleAuthState() { ... } // LINT: Private method should not be documented
// Validates user input
void _validateInput(String input) { ... } // LINT: Private method should not be documented
Example of code that doesn't trigger this rule:
void _handleAuthState() { ... } // No documentation - good
/// Public method that should be documented
void authenticate() { ... } // Public method - documentation required
Constructors
- NoInternalMethodDocs()
-
const
Properties
- code → LintCode
-
The
LintCodethat thisLintRulemay emit.finalinherited - enabledByDefault → bool
-
Whether the lint rule is on or off by default in an empty analysis_options.yaml
no setterinherited
-
filesToAnalyze
→ List<
String> -
A list of glob patterns matching the files that run cares about.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFixes(
) → List< Fix> -
Obtains the list of
Fixassociated with thisLintRule.inherited -
isEnabled(
CustomLintConfigs configs) → bool -
Checks whether this lint rule is enabled in a configuration file.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
CustomLintResolver resolver, ErrorReporter reporter, CustomLintContext context) → void - Emits lints for a given file.
-
startUp(
CustomLintResolver resolver, CustomLintContext context) → Future< void> -
Emits lints for a given file.
inherited
-
testAnalyzeAndRun(
File file) → Future< List< AnalysisError> > -
Analyze a Dart file and runs this assist in test mode.
inherited
-
testRun(
ResolvedUnitResult result, {Pubspec? pubspec}) → Future< List< AnalysisError> > -
Runs this assist in test mode.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited